@@ -83,7 +83,6 @@
 #include <KToggleAction>
 #include <KCMultiDialog>
 #include <KXMLGUIClient>
-#include <KMessageBox>
 
 #include <QActionGroup>
 #include <QHBoxLayout>
@@ -94,7 +93,6 @@
 #include <QSplitter>
 #include <QStackedWidget>
 #include <QDBusConnection>
-#include <QDesktopServices>
 #include <ItemModifyJob>
 #include <KPimPrintPreviewDialog>
 
@@ -234,8 +232,8 @@ MainWidget::MainWidget(KXMLGUIClient *guiClient, QWidget *parent)
     connect(mCollectionView->model(), &QAbstractItemModel::rowsInserted,
             this, &MainWidget::slotCheckNewCalendar);
 
-    connect(mCollectionView, SIGNAL(currentChanged(Akonadi::Collection)),
-            this, SLOT(slotCurrentCollectionChanged(Akonadi::Collection)));
+    connect(mCollectionView, QOverload<const Akonadi::Collection &>::of(&Akonadi::EntityTreeView::currentChanged),
+            this, &MainWidget::slotCurrentCollectionChanged);
 
     KSelectionProxyModel *selectionProxyModel
         = new KSelectionProxyModel(mCollectionSelectionModel, this);
@@ -308,11 +306,10 @@ MainWidget::MainWidget(KXMLGUIClient *guiClient, QWidget *parent)
     connect(mActionManager->action(
                 Akonadi::StandardActionManager::CollectionProperties), &QAction::triggered, mManageShowCollectionProperties, &ManageShowCollectionProperties::showCollectionProperties);
 
-    connect(mItemView, SIGNAL(currentChanged(Akonadi::Item)),
-            this, SLOT(itemSelected(Akonadi::Item)));
-    connect(mItemView, SIGNAL(doubleClicked(Akonadi::Item)),
-            mActionManager->action(Akonadi::StandardContactActionManager::EditItem),
-            SLOT(trigger()));
+    connect(mItemView, QOverload<const Akonadi::Item &>::of(&Akonadi::EntityTreeView::currentChanged),
+            this, &MainWidget::itemSelected);
+    connect(mItemView, QOverload<const Akonadi::Item &>::of(&Akonadi::EntityTreeView::doubleClicked),
+            mActionManager->action(Akonadi::StandardContactActionManager::EditItem), &QAction::trigger);
     connect(mItemView->selectionModel(), &QItemSelectionModel::currentChanged,
             this, &MainWidget::itemSelectionChanged);
 
@@ -374,12 +371,13 @@ void MainWidget::initializeImportExportPlugin(KActionCollection *collection)
 
 void MainWidget::configure()
 {
-    KCMultiDialog dlg(this);
-    dlg.addModule(QStringLiteral("akonadicontact_actions.desktop"));
-    dlg.addModule(QStringLiteral("kcmldap.desktop"));
-    dlg.addModule(QStringLiteral("kaddressbook_config_plugins.desktop"));
+    QPointer<KCMultiDialog> dlg = new KCMultiDialog(this);
+    dlg->addModule(QStringLiteral("akonadicontact_actions.desktop"));
+    dlg->addModule(QStringLiteral("kcmldap.desktop"));
+    dlg->addModule(QStringLiteral("kaddressbook_config_plugins.desktop"));
 
-    dlg.exec();
+    dlg->exec();
+    delete dlg;
 }
 
 void MainWidget::handleCommandLine(const QStringList &arguments)
@@ -413,9 +411,7 @@ void MainWidget::delayedInit()
     const KConfigGroup group(Settings::self()->config(), "UiState_ContactView");
     KPIM::UiStateSaver::restoreState(mItemView, group);
 
-#if defined(HAVE_PRISON)
     mXmlGuiClient->actionCollection()->action(QStringLiteral("options_show_qrcodes"))->setChecked(showQRCodes());
-#endif
 
     connect(GlobalContactModel::instance()->model(), &QAbstractItemModel::modelAboutToBeReset,
             this, &MainWidget::saveState);
@@ -620,7 +616,7 @@ void MainWidget::setupActions(KActionCollection *collection)
                                                             QStringLiteral("theme.desktop"),
                                                             collection,
                                                             QStringLiteral("kaddressbook/viewertemplates/"));
-    mGrantleeThemeManager->setDownloadNewStuffConfigFile(QStringLiteral("kaddressbook_themes.knsrc"));
+    mGrantleeThemeManager->setDownloadNewStuffConfigFile(QStringLiteral(":/knsrc/data/kaddressbook_themes.knsrc"));
     connect(mGrantleeThemeManager, &GrantleeTheme::ThemeManager::grantleeThemeSelected, this, &MainWidget::slotGrantleeThemeSelected);
     connect(mGrantleeThemeManager, &GrantleeTheme::ThemeManager::updateThemes, this, &MainWidget::slotGrantleeThemesUpdated);
 
@@ -655,13 +651,10 @@ void MainWidget::setupActions(KActionCollection *collection)
     action->setWhatsThis(i18n("Select all contacts in the current address book view."));
     connect(action, &QAction::triggered, mItemView, &Akonadi::EntityTreeView::selectAll);
 
-#if defined(HAVE_PRISON)
-    KToggleAction *qrtoggleAction;
-    qrtoggleAction = collection->add<KToggleAction>(QStringLiteral("options_show_qrcodes"));
+    KToggleAction *qrtoggleAction = collection->add<KToggleAction>(QStringLiteral("options_show_qrcodes"));
     qrtoggleAction->setText(i18n("Show QR Codes"));
     qrtoggleAction->setWhatsThis(i18n("Show QR Codes in the contact."));
     connect(qrtoggleAction, &KToggleAction::toggled, this, &MainWidget::setQRCodeShow);
-#endif
 
     mViewModeGroup = new QActionGroup(this);
 
@@ -684,7 +677,7 @@ void MainWidget::setupActions(KActionCollection *collection)
     collection->setDefaultShortcut(act, QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_3));
     collection->addAction(QStringLiteral("view_mode_3columns"), act);
 
-    connect(mViewModeGroup, SIGNAL(triggered(QAction *)), SLOT(setViewMode(QAction *)));
+    connect(mViewModeGroup, QOverload<QAction *>::of(&QActionGroup::triggered), this, QOverload<QAction *>::of(&MainWidget::setViewMode));
 
     KToggleAction *actTheme = mGrantleeThemeManager->actionForTheme();
     if (actTheme) {
@@ -697,11 +690,11 @@ void MainWidget::setupActions(KActionCollection *collection)
     connect(mQuickSearchAction, &QAction::triggered, mQuickSearchWidget, &QuickSearchWidget::slotFocusQuickSearch);
     collection->setDefaultShortcut(mQuickSearchAction, QKeySequence(Qt::ALT + Qt::Key_Q));
 
-    if (!qEnvironmentVariableIsEmpty("KDEPIM_BALOO_DEBUG")) {
-        action = collection->addAction(QStringLiteral("debug_baloo"));
+    if (!qEnvironmentVariableIsEmpty("KDEPIM_DEBUGGING")) {
+        action = collection->addAction(QStringLiteral("debug_akonadi_search"));
         //Don't translate it. It's just for debug
-        action->setText(QStringLiteral("Debug baloo..."));
-        connect(action, &QAction::triggered, this, &MainWidget::slotDebugBaloo);
+        action->setText(QStringLiteral("Debug Akonadi Search..."));
+        connect(action, &QAction::triggered, this, &MainWidget::slotDebugAkonadiSearch);
     }
 
     mServerSideSubscription = new QAction(QIcon::fromTheme(QStringLiteral("folder-bookmarks")), i18n("Serverside Subscription..."), this);
@@ -717,10 +710,10 @@ void MainWidget::printPreview()
     printer.setOutputFormat(QPrinter::PdfFormat);
     printer.setCollateCopies(true);
 
-    PimCommon::KPimPrintPreviewDialog previewdlg(&printer, this);
+    QPointer<PimCommon::KPimPrintPreviewDialog> previewdlg = new PimCommon::KPimPrintPreviewDialog(&printer, this);
     KABPrinting::PrintingWizard wizard(&printer, mItemView->selectionModel(), this);
     wizard.setDefaultAddressBook(currentAddressBook());
-    connect(&previewdlg, &QPrintPreviewDialog::paintRequested, this, [&wizard]() {
+    connect(previewdlg.data(), &QPrintPreviewDialog::paintRequested, this, [&wizard]() {
         wizard.print();
     });
 
@@ -729,8 +722,9 @@ void MainWidget::printPreview()
         Settings::self()->setDefaultFileName(printer.outputFileName());
         Settings::self()->setPrintingStyle(wizard.printingStyle());
         Settings::self()->setSortOrder(wizard.sortOrder());
-        previewdlg.exec();
+        previewdlg->exec();
     }
+    delete previewdlg;
 }
 
 void MainWidget::print()
@@ -807,18 +801,13 @@ void MainWidget::selectFirstItem()
 
 bool MainWidget::showQRCodes()
 {
-#if defined(HAVE_PRISON)
     KConfig config(QStringLiteral("akonadi_contactrc"));
     KConfigGroup group(&config, QStringLiteral("View"));
     return group.readEntry("QRCodes", true);
-#else
-    return true;
-#endif
 }
 
 void MainWidget::setQRCodeShow(bool on)
 {
-#if defined(HAVE_PRISON)
     // must write the configuration setting first before updating the view.
     KConfig config(QStringLiteral("akonadi_contactrc"));
     KConfigGroup group(&config, QStringLiteral("View"));
@@ -828,9 +817,6 @@ void MainWidget::setQRCodeShow(bool on)
         mFormatter->setShowQRCode(on);
         mContactDetails->setShowQRCode(on);
     }
-#else
-    Q_UNUSED(on);
-#endif
 }
 
 Akonadi::Item::List MainWidget::selectedItems()
@@ -1021,7 +1007,7 @@ const Akonadi::Item::List MainWidget::collectSelectedAllContactsItem()
     return collectSelectedAllContactsItem(mItemView->selectionModel());
 }
 
-void MainWidget::slotDebugBaloo()
+void MainWidget::slotDebugAkonadiSearch()
 {
     const Akonadi::Item::List lst = collectSelectedAllContactsItem(mItemView->selectionModel());
     if (lst.isEmpty()) {
